@@ -24,13 +24,12 @@ import posixpath
 import textwrap
 import platform
 import importlib
-import operator
 import datetime
 import subprocess
 import re
+import contextlib
 
 import pytest
-import packaging.version
 
 import path
 from path import Path
@@ -40,23 +39,14 @@ from path import SpecialResolver
 from path import Multi
 
 
-def p(**choices):
+def os_choose(**choices):
     """ Choose a value from several possible values, based on os.name """
     return choices[os.name]
 
 
-def mac_version(target, comparator=operator.ge):
-    """
-    Return True if on a Mac whose version passes the comparator.
-    """
-    current_ver = packaging.version.parse(platform.mac_ver()[0])
-    target_ver = packaging.version.parse(target)
-    return platform.system() == 'Darwin' and comparator(current_ver, target_ver)
-
-
 class TestBasics:
     def test_relpath(self):
-        root = Path(p(nt='C:\\', posix='/'))
+        root = Path(os_choose(nt='C:\\', posix='/'))
         foo = root / 'foo'
         quux = foo / 'quux'
         bar = foo / 'bar'
@@ -89,15 +79,9 @@ class TestBasics:
             assert d.relpathto(boz) == boz
 
     def test_construction_from_none(self):
-        """
-
-        """
-        try:
+        """"""
+        with pytest.raises(TypeError):
             Path(None)
-        except TypeError:
-            pass
-        else:
-            raise Exception("DID NOT RAISE")
 
     def test_construction_from_int(self):
         """
@@ -119,32 +103,33 @@ class TestBasics:
         # Test p1/p1.
         p1 = Path("foo")
         p2 = Path("bar")
-        assert p1 / p2 == p(nt='foo\\bar', posix='foo/bar')
+        assert p1 / p2 == os_choose(nt='foo\\bar', posix='foo/bar')
 
     def test_properties(self):
         # Create sample path object.
-        f = p(
-            nt='C:\\Program Files\\Python\\Lib\\xyzzy.py',
-            posix='/usr/local/python/lib/xyzzy.py',
+        f = Path(
+            os_choose(
+                nt='C:\\Program Files\\Python\\Lib\\xyzzy.py',
+                posix='/usr/local/python/lib/xyzzy.py',
+            )
         )
-        f = Path(f)
 
         # .parent
         nt_lib = 'C:\\Program Files\\Python\\Lib'
         posix_lib = '/usr/local/python/lib'
-        expected = p(nt=nt_lib, posix=posix_lib)
+        expected = os_choose(nt=nt_lib, posix=posix_lib)
         assert f.parent == expected
 
         # .name
         assert f.name == 'xyzzy.py'
-        assert f.parent.name == p(nt='Lib', posix='lib')
+        assert f.parent.name == os_choose(nt='Lib', posix='lib')
 
         # .ext
         assert f.ext == '.py'
         assert f.parent.ext == ''
 
         # .drive
-        assert f.drive == p(nt='C:', posix='')
+        assert f.drive == os_choose(nt='C:', posix='')
 
     def test_methods(self):
         # .abspath()
@@ -155,11 +140,11 @@ class TestBasics:
         assert isinstance(cwd, Path)
         assert cwd == os.getcwd()
 
+    @pytest.mark.skipif('not hasattr(os.path, "splitunc")')
     def test_UNC(self):
-        if hasattr(os.path, 'splitunc'):
-            p = Path(r'\\python1\share1\dir1\file1.txt')
-            assert p.uncshare == r'\\python1\share1'
-            assert p.splitunc() == os.path.splitunc(str(p))
+        p = Path(r'\\python1\share1\dir1\file1.txt')
+        assert p.uncshare == r'\\python1\share1'
+        assert p.splitunc() == os.path.splitunc(str(p))
 
     def test_explicit_module(self):
         """
@@ -187,7 +172,7 @@ class TestBasics:
     def test_joinpath_on_instance(self):
         res = Path('foo')
         foo_bar = res.joinpath('bar')
-        assert foo_bar == p(nt='foo\\bar', posix='foo/bar')
+        assert foo_bar == os_choose(nt='foo\\bar', posix='foo/bar')
 
     def test_joinpath_to_nothing(self):
         res = Path('foo')
@@ -196,16 +181,12 @@ class TestBasics:
     def test_joinpath_on_class(self):
         "Construct a path from a series of strings"
         foo_bar = Path.joinpath('foo', 'bar')
-        assert foo_bar == p(nt='foo\\bar', posix='foo/bar')
+        assert foo_bar == os_choose(nt='foo\\bar', posix='foo/bar')
 
     def test_joinpath_fails_on_empty(self):
         "It doesn't make sense to join nothing at all"
-        try:
+        with pytest.raises(TypeError):
             Path.joinpath()
-        except TypeError:
-            pass
-        else:
-            raise Exception("did not raise")
 
     def test_joinpath_returns_same_type(self):
         path_posix = Path.using_module(posixpath)
@@ -256,7 +237,9 @@ class TestSymbolicLinksWalk:
         (sub / 'file').touch()
         assert len(list(root.walk())) == 4
 
-        skip_links = path.Traversal(lambda item: item.isdir() and not item.islink(),)
+        skip_links = path.Traversal(
+            lambda item: item.isdir() and not item.islink(),
+        )
         assert len(list(skip_links(root.walk()))) == 3
 
 
@@ -410,12 +393,10 @@ class TestScratchDir:
             assert files == files2
         finally:
             for f in files:
-                try:
+                with contextlib.suppress(Exception):
                     f.remove()
-                except Exception:
-                    pass
 
-    @pytest.mark.skip(
+    @pytest.mark.skipif(
         platform.system() != "Linux",
         reason="Only Linux allows writing invalid encodings",
     )
@@ -582,9 +563,11 @@ class TestScratchDir:
         self.assertList(d.walkfiles('*.tmp'), [e / 'x.tmp' for e in dirs])
         self.assertList(d.walkdirs('*.tmp'), [d / 'xdir.tmp'])
 
-    @pytest.mark.parametrize("encoding", ('UTF-8', 'UTF-16BE', 'UTF-16LE', 'UTF-16'))
+    encodings = 'UTF-8', 'UTF-16BE', 'UTF-16LE', 'UTF-16'
+
+    @pytest.mark.parametrize("encoding", encodings)
     def test_unicode(self, tmpdir, encoding):
-        """ Test that path works with the specified encoding,
+        """Test that path works with the specified encoding,
         which must be capable of representing the entire range of
         Unicode codepoints.
         """
@@ -720,13 +703,12 @@ class TestScratchDir:
         (sub / 'afile').write_text('something')
         sub.rmtree_p()
         assert not sub.exists()
-        try:
-            sub.rmtree_p()
-        except OSError:
-            self.fail(
-                "Calling `rmtree_p` on non-existent directory "
-                "should not raise an exception."
-            )
+
+    def test_rmtree_p_nonexistent(self, tmpdir):
+        d = Path(tmpdir)
+        sub = d / 'subfolder'
+        assert not sub.exists()
+        sub.rmtree_p()
 
     def test_rmdir_p_exists(self, tmpdir):
         """
@@ -1038,9 +1020,6 @@ class TestPatternMatching:
         assert p / 'sub1' / 'foo' / 'bar.Txt' in files
 
 
-@pytest.mark.skipif(
-    sys.version_info < (2, 6), reason="in_place requires io module in Python 2.6"
-)
 class TestInPlace:
     reference_content = textwrap.dedent(
         """
